Struct amazon_sp_listings_items::models::listings_item_submission_response::ListingsItemSubmissionResponse
source · [−]pub struct ListingsItemSubmissionResponse {
pub sku: String,
pub status: Status,
pub submission_id: String,
pub issues: Option<Vec<Issue>>,
}Expand description
ListingsItemSubmissionResponse : Response containing the results of a submission to the Selling Partner API for Listings Items.
Fields
sku: StringA selling partner provided identifier for an Amazon listing.
status: StatusThe status of the listings item submission.
submission_id: StringThe unique identifier of the listings item submission.
issues: Option<Vec<Issue>>Listings item issues related to the listings item submission.
Implementations